@@ -1,7 +1,7 @@
 /* ---------------------------------------------------------------------------
  ADOL-C -- Automatic Differentiation by Overloading in C++
 
- Revision: $Id: advector.h 427 2013-04-03 09:30:24Z kulshres $
+ Revision: $Id: advector.h 659 2015-12-15 10:17:20Z kulshres $
  Contents: advector.h contains a vector<adouble> implementation
            that is able to trace subscripting operations.
 
@@ -21,8 +21,6 @@
 #ifdef __cplusplus
 #include <vector>
 
-#include <adolc/adouble.h>
-
 /****************************************************************************/
 /*                                           THIS IS ONLY FOR TAPED VERSION */
 #if !defined(TAPELESS)
@@ -46,6 +44,7 @@ class ADOLC_DLL_EXPORT adubref {
      */
     friend ADOLC_DLL_EXPORT class adub;
     friend ADOLC_DLL_EXPORT class advector;
+    friend ADOLC_DLL_EXPORT class pdouble;
 protected:
     locint location;
     locint refloc;
@@ -70,6 +69,12 @@ protected:
 		" variable from adub\n");
         exit(-2);
     }
+    adubref( const adubref& ) {
+        fprintf(DIAG_OUT,"ADOL-C error: illegal copy construction of adubref"
+               " variable\n");
+        exit(-2);
+    }
+    bool isInit;  // marker if the badouble is properly initialized
 public:
     /* adub prevents postfix operators to occur on the left
        side of an assignment which would not work  */
@@ -80,27 +85,38 @@ public:
     adubref& operator = ( double );
     adubref& operator = ( const badouble& );
     adubref& operator = ( const adubref& );
+    adubref& operator = ( const pdouble& );
     adubref& operator +=  ( double );
     adubref& operator +=  ( const badouble& );
+    adubref& operator +=  ( const pdouble& );
     adubref& operator -=  ( double x );
     adubref& operator -=  ( const badouble& );
+    adubref& operator -=  ( const pdouble& );
     adubref& operator *=  ( double x );
     adubref& operator *=  ( const badouble& );
-    adubref& operator /=  ( double x );
-    adubref& operator /=  ( const badouble& );
+    adubref& operator *=  ( const pdouble& );
+    inline adubref& operator /=  ( double x );
+    inline adubref& operator /=  ( const badouble& );
+    inline adubref& operator /=  ( const pdouble&);
+
     adubref& operator <<= ( double );
     void declareIndependent();
     adubref& operator >>= ( double& );
     void declareDependent();
     operator adub() const;
-    friend ADOLC_DLL_EXPORT void condassign(adubref, const badouble&, const badouble&, const badouble&);
-    friend ADOLC_DLL_EXPORT void condassign(adubref, const badouble&, const badouble&);
+    friend ADOLC_DLL_EXPORT void condassign(adubref&, const badouble&, const badouble&, const badouble&);
+    friend ADOLC_DLL_EXPORT void condassign(adubref&, const badouble&, const badouble&);
+    ~adubref();
 };
 
+/* adolc_vec_copy(dest,src,size); */
+void ADOLC_DLL_EXPORT adolc_vec_copy(adouble *const, const adouble*const, locint);
+/* adolc_vec_axpy(res,a,x,y,size); <=> res = a*x + y  */
+void ADOLC_DLL_EXPORT adolc_vec_axpy(adouble *const, const badouble&, const adouble*const, const adouble*const, locint);
+
 class advector {
 private:
     struct ADOLC_DLL_EXPORT blocker {
-	adouble *dflt;
 	blocker() {}
 	blocker(size_t n);
 	~blocker() {}
@@ -109,13 +125,16 @@ private:
     ADOLC_DLL_EXPORT bool nondecreasing() const;
 public:
     ADOLC_DLL_EXPORT advector() : blk(), data() {}
-    ADOLC_DLL_EXPORT explicit advector(size_t n) : blk(n), data(n, *blk.dflt) { delete blk.dflt; }
+    ADOLC_DLL_EXPORT explicit advector(size_t n) : blk(n), data(n) {}
     ADOLC_DLL_EXPORT ~advector() {}
-    ADOLC_DLL_EXPORT advector(const advector& x) : blk(x.data.size()), data(x.data) { delete blk.dflt; }
-    ADOLC_DLL_EXPORT advector(const std::vector<adouble>& v) : blk(v.size()), data(v) { delete blk.dflt; }
+    ADOLC_DLL_EXPORT advector(const advector& x) : blk(x.size()), data(x.size()) {  adolc_vec_copy(data.data(),x.data.data(),x.size()); }
+    // in the above copy we are sure of contiguous locations
+    // but not so in the one below
+    ADOLC_DLL_EXPORT advector(const std::vector<adouble>& v) : blk(v.size()), data(v) {}
     ADOLC_DLL_EXPORT size_t size() const { return data.size(); }
     ADOLC_DLL_EXPORT operator const std::vector<adouble>&() const { return data; }
     ADOLC_DLL_EXPORT operator std::vector<adouble>&() { return data; }
+    ADOLC_DLL_EXPORT operator adouble*() { return data.data(); }
     ADOLC_DLL_EXPORT adub operator[](const badouble& index) const;
     ADOLC_DLL_EXPORT adubref operator[](const badouble& index);
     ADOLC_DLL_EXPORT adouble& operator[](size_t i) { return data[i]; }
@@ -123,6 +142,21 @@ public:
     ADOLC_DLL_EXPORT adouble lookupindex(const badouble& x, const badouble& y) const;
 };
 
+inline adubref& adubref::operator /= (double y) {
+    *this *=  (1.0/y);
+    return *this;
+}
+
+
+inline adubref& adubref::operator /= (const badouble& y) {
+    *this *=  (1.0/y);
+    return *this;
+}
+
+inline adubref& adubref::operator /= (const pdouble& p) {
+    *this *= recipr(p); 
+    return *this;
+}
 #endif /* TAPELESS */
 #endif /* __cplusplus */
 #endif /* ADOLC_ADVECTOR_H */
