@@ -1,7 +1,7 @@
 /*----------------------------------------------------------------------------
  ADOL-C -- Automatic Differentiation by Overloading in C++
  File:     tapedoc/tapedoc.c
- Revision: $Id: tapedoc.c 527 2014-07-15 14:09:31Z kulshres $
+ Revision: $Id: tapedoc.c 603 2015-03-24 03:35:03Z kulshres $
  Contents: Routine tape_doc(..) writes the taped operations in LaTeX-code 
            to the file tape_doc.tex
  
@@ -18,6 +18,7 @@
 #include "oplate.h"
 #include "taping_p.h"
 #include <adolc/adalloc.h>
+#include "dvlparms.h"
 
 #include <math.h>
 #include <string.h>
@@ -116,6 +117,8 @@ void filewrite( unsigned short opcode, const char* opString, int nloc, int *loc,
     
     /* write locations (max 4) right-justified */
     fprintf(fp," &");
+    if (opcode==ext_diff || opcode==ext_diff_iArr || opcode==ext_diff_v2)
+        opcode = ext_diff;
     if (opcode!=ext_diff) { /* default */
         for(i=0; i<(4-nloc); i++)
             fprintf(fp," &");
@@ -132,8 +135,10 @@ void filewrite( unsigned short opcode, const char* opString, int nloc, int *loc,
     /* write values */
 #ifdef ADOLC_TAPE_DOC_VALUES /* values + constants */
     /* constants (max 2) */
-    if (opcode==ext_diff)
+    if (opcode==ext_diff || opcode == vec_copy)
         nloc=0;
+    if (opcode == vec_dot || opcode == vec_axpy)
+        nloc=1;
     for(i=0; i<(2-ncst); i++)
         fprintf(fp," &");
     for(i=0; i<ncst; i++)
@@ -243,7 +248,9 @@ void tape_doc(short tnum,         /* tape id */
     int loc_a[maxLocsPerOp];
     double val_a[4]={0,0,0,0}, cst_d[2]={0,0};
     const char* opName;
-
+#ifdef ADOLC_TAPE_DOC_VALUES
+	locint qq;
+#endif
     ADOLC_OPENMP_THREAD_NUMBER;
     ADOLC_OPENMP_GET_THREAD_NUMBER;
 
@@ -1150,6 +1157,57 @@ void tape_doc(short tnum,         /* tape id */
                 filewrite(operation,"cond assign s $\\longrightarrow$",3,loc_a,val_a,1,cst_d);
                 break;
 
+            case vec_copy:
+                res = get_locint_f();
+                arg = get_locint_f();
+                size = get_locint_f();
+                loc_a[0] = res;
+                loc_a[1] = arg;
+                loc_a[2] = size;
+#ifdef ADOLC_TAPE_DOC_VALUES
+                for(qq=0;qq<size;qq++) 
+                    dp_T0[res+qq] = dp_T0[arg+qq];
+#endif
+                filewrite(operation,"vec copy $\\longrightarrow$",3,loc_a,val_a,0,cst_d);
+                break;
+
+            case vec_dot:
+                res = get_locint_f();
+                arg1 = get_locint_f();
+                arg2 = get_locint_f();
+                size = get_locint_f();
+                loc_a[0] = res;
+                loc_a[1] = arg1;
+                loc_a[2] = arg2;
+                loc_a[3] = size;
+#ifdef ADOLC_TAPE_DOC_VALUES
+                dp_T0[res] = 0;
+                for(qq=0;qq<size;qq++) 
+                    dp_T0[res] += dp_T0[arg1+qq] *  dp_T0[arg2+qq];
+                val_a[0] = dp_T0[res];
+#endif
+                filewrite(operation,"vec dot $\\longrightarrow$",4,loc_a,val_a,0,cst_d);
+                break;
+
+            case vec_axpy:
+                res = get_locint_f();
+                arg = get_locint_f();
+                arg1 = get_locint_f();
+                arg2 = get_locint_f();
+                size = get_locint_f();
+                loc_a[0] = res;
+                loc_a[1] = arg;
+                loc_a[1] = arg1;
+                loc_a[2] = arg2;
+                loc_a[3] = size;
+#ifdef ADOLC_TAPE_DOC_VALUES
+                val_a[0] = dp_T0[arg];
+                for(qq=0;qq<size;qq++) 
+                    dp_T0[res+qq] = dp_T0[arg] * dp_T0[arg1+qq] + dp_T0[arg2+qq];
+#endif
+                filewrite(operation,"vec axpy $\\longrightarrow$",4,loc_a,val_a,0,cst_d);
+                break;
+
 
                 /****************************************************************************/
                 /*                                                          REMAINING STUFF */
@@ -1203,7 +1261,21 @@ void tape_doc(short tnum,         /* tape id */
                 loc_a[3] = get_locint_f(); /* dummy */
                 filewrite(operation, "extern diff iArr",3, loc_a, val_a, 0, cst_d);
                 break;
-
+            case ext_diff_v2:
+                loc_a[0] = get_locint_f(); /* index */
+                loc_a[1] = get_locint_f(); /* iArr length */
+                for (l=0; l<loc_a[1];++l) get_locint_f(); /* iArr */
+                get_locint_f(); /* iArr length again */
+                loc_a[1] = get_locint_f(); /* nin */
+                loc_a[2] = get_locint_f(); /* nout */
+                for (l=0; l<loc_a[1];++l) { get_locint_f(); get_locint_f(); } 
+                /* input vectors sizes and start locs */
+                for (l=0; l<loc_a[2];++l) { get_locint_f(); get_locint_f(); } 
+                /* output vectors sizes and start locs */
+                get_locint_f(); /* nin again */
+                get_locint_f(); /* nout again */
+                filewrite(operation, "extern diff v2",3, loc_a, val_a, 0, cst_d);
+                break;
 #ifdef ADOLC_AMPI_SUPPORT
             case ampi_send:
 	        loc_a[0] = get_locint_f();   /* start loc */
